[java-identity-provider COMMIT] in /trunk/idp-core/src/main/java/net/shibboleth/idp/service: AbstractReloadableServic...

noreply at shibboleth.net noreply at shibboleth.net
Mon Jan 28 18:52:17 EST 2013


Author: tzeller
Date: Mon Jan 28 18:52:17 2013
New Revision: 4276

URL: http://svn.shibboleth.net/view/java-identity-provider?rev=4276&view=rev
Log:
Method name typo.

Modified:
    trunk/idp-core/src/main/java/net/shibboleth/idp/service/AbstractReloadableService.java
    trunk/idp-core/src/main/java/net/shibboleth/idp/service/AbstractSpringReloadableService.java

Modified: trunk/idp-core/src/main/java/net/shibboleth/idp/service/AbstractReloadableService.java
URL: http://svn.shibboleth.net/view/java-identity-provider/trunk/idp-core/src/main/java/net/shibboleth/idp/service/AbstractReloadableService.java?rev=4276&r1=4275&r2=4276&view=diff
==============================================================================
--- trunk/idp-core/src/main/java/net/shibboleth/idp/service/AbstractSpringReloadableService.java (original)
+++ trunk/idp-core/src/main/java/net/shibboleth/idp/service/AbstractSpringReloadableService.java Mon Jan 28 18:52:17 2013
@@ -156,7 +156,7 @@
     }
 
     /** {@inheritDoc} */
-    protected void doPostRelaod(final HashMap context) throws ServiceException {
+    protected void doPostReload(final HashMap context) throws ServiceException {
         GenericApplicationContext appCtx =
                 (GenericApplicationContext) context.get(AbstractSpringService.APP_CTX_CTX_KEY);
         serviceContext = appCtx;



More information about the commits mailing list
--- trunk/idp-core/src/main/java/net/shibboleth/idp/service/AbstractReloadableService.java (original)
+++ trunk/idp-core/src/main/java/net/shibboleth/idp/service/AbstractReloadableService.java Mon Jan 28 18:52:17 2013
@@ -142,7 +142,7 @@
      * {@inheritDoc}
      * 
      * This implementation will set the current state to {@link ReloadableService#STATE_RELOADING}, call
      * {@link #doPreReload(HashMap)}, {@link #doReload(HashMap)}, and {@link #doPostRelaod(HashMap)} in turn. It will
      * manage the {@link #lastReloadInstant} and {@link #lastSuccessfulReleaseIntant} information and record the reload
      * performance event.
      */
@@ -160,7 +160,7 @@
 
             doPreReload(context);
             doReload(context);
-            doPostRelaod(context);
+            doPostReload(context);
 
             lastSuccessfulReleaseIntant = now;
             perfEvent.stopTime(true);
@@ -192,7 +192,7 @@
      * This method is called within the service write lock and may change service state.
      * 
      * @param context Collection of data carried through {@link #doPreReload(HashMap)}, {@link #doReload(HashMap)}, and
      *            {@link #doPostRelaod(HashMap)}. This is an appropriate place to keep state as the reload process
      *            progresses.
      * 
      * @throws ServiceException thrown if there is a problem reloading the service
@@ -208,7 +208,7 @@
      * This method is called within the service write lock and may change service state.
      * 
      * @param context Collection of data carried through {@link #doPreReload(HashMap)}, {@link #doReload(HashMap)}, and
      *            {@link #doPostRelaod(HashMap)}. This is an appropriate place to keep state as the reload process
      *            progresses
      * 
      * @throws ServiceException thrown if there is a problem reloading the service
@@ -225,12 +225,12 @@
      * The default implementation of this method does not do anything.
      * 
      * @param context Collection of data carried through {@link #doPreReload(HashMap)}, {@link #doReload(HashMap)}, and
      *            {@link #doPostRelaod(HashMap)}. This is an appropriate place to keep state as the reload process
      *            progresses
      * 
      * @throws ServiceException thrown if there is a problem reloading the service
      */
-    protected void doPostRelaod(final HashMap context) throws ServiceException {
+    protected void doPostReload(final HashMap context) throws ServiceException {
         log.info("Service '{}' reloaded", getId());
     }
 
@@ -142,7 +142,7 @@
      * 
      * This implementation will set the current state to {@link ReloadableService#STATE_RELOADING}, call
-     * {@link #doPreReload(HashMap)}, {@link #doReload(HashMap)}, and {@link #doPostRelaod(HashMap)} in turn. It will
+     * {@link #doPreReload(HashMap)}, {@link #doReload(HashMap)}, and {@link #doPostReload(HashMap)} in turn. It will
      * manage the {@link #lastReloadInstant} and {@link #lastSuccessfulReleaseIntant} information and record the reload
      * performance event.
@@ -192,7 +192,7 @@
      * 
      * @param context Collection of data carried through {@link #doPreReload(HashMap)}, {@link #doReload(HashMap)}, and
-     *            {@link #doPostRelaod(HashMap)}. This is an appropriate place to keep state as the reload process
+     *            {@link #doPostReload(HashMap)}. This is an appropriate place to keep state as the reload process
      *            progresses.
      * 
@@ -208,7 +208,7 @@
      * 
      * @param context Collection of data carried through {@link #doPreReload(HashMap)}, {@link #doReload(HashMap)}, and
-     *            {@link #doPostRelaod(HashMap)}. This is an appropriate place to keep state as the reload process
+     *            {@link #doPostReload(HashMap)}. This is an appropriate place to keep state as the reload process
      *            progresses
      * 
@@ -225,12 +225,12 @@
      * 
      * @param context Collection of data carried through {@link #doPreReload(HashMap)}, {@link #doReload(HashMap)}, and
-     *            {@link #doPostRelaod(HashMap)}. This is an appropriate place to keep state as the reload process
+     *            {@link #doPostReload(HashMap)}. This is an appropriate place to keep state as the reload process
      *            progresses
      * 

Modified: trunk/idp-core/src/main/java/net/shibboleth/idp/service/AbstractSpringReloadableService.java
URL: http://svn.shibboleth.net/view/java-identity-provider/trunk/idp-core/src/main/java/net/shibboleth/idp/service/AbstractSpringReloadableService.java?rev=4276&r1=4275&r2=4276&view=diff
==============================================================================